==> qt-creator-1.3.1-src.zip: qt-creator-1.3.1-src/src/plugins/qt4projectmanager/wizards/guiappwizard.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef GUIAPPWIZARD_H
#define GUIAPPWIZARD_H

#include "qtwizard.h"

namespace Qt4ProjectManager {
namespace Internal {

struct GuiAppParameters;

class GuiAppWizard : public QtWizard
{
    Q_DISABLE_COPY(GuiAppWizard)
    Q_OBJECT

public:
    GuiAppWizard();

protected:
    virtual QWizard *createWizardDialog(QWidget *parent,
                                        const QString &defaultPath,
                                        const WizardPageList &extensionPages) const;

    virtual Core::GeneratedFiles generateFiles(const QWizard *w,
                                               QString *errorMessage) const;

private:
    static bool parametrizeTemplate(const QString &templatePath, const QString &templateName,
                                    const GuiAppParameters &params,
                                    QString *target, QString *errorMessage);
};

} // namespace Internal
} // namespace Qt4ProjectManager

#endif // GUIAPPWIZARD_H

==> qt-creator-2.0.0-rc1-src.zip: qt-creator-2.0.0-rc1-src/src/plugins/qt4projectmanager/wizards/guiappwizard.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef GUIAPPWIZARD_H
#define GUIAPPWIZARD_H

#include "qtwizard.h"

namespace Qt4ProjectManager {
namespace Internal {

struct GuiAppParameters;

class GuiAppWizard : public QtWizard
{
    Q_DISABLE_COPY(GuiAppWizard)
    Q_OBJECT

public:
    GuiAppWizard();

protected:
    GuiAppWizard(const QString &id,
                 const QString &category,
                 const QString &categoryTranslationScope,
                 const QString &displayCategory,
                 const QString &name,
                 const QString &description,
                 const QIcon &icon,
                 bool createMobile);
    virtual QWizard *createWizardDialog(QWidget *parent,
                                        const QString &defaultPath,
                                        const WizardPageList &extensionPages) const;

    virtual Core::GeneratedFiles generateFiles(const QWizard *w,
                                               QString *errorMessage) const;

private:
    static bool parametrizeTemplate(const QString &templatePath, const QString &templateName,
                                    const GuiAppParameters &params,
                                    QString *target, QString *errorMessage);

    bool m_createMobileProject;
};

} // namespace Internal
} // namespace Qt4ProjectManager

#endif // GUIAPPWIZARD_H
